@@ -66,7 +66,7 @@ import java.util.ListResourceBundle;
 public class FormatData_mai extends ListResourceBundle {
     @Override
     protected final Object[][] getContents() {
-        final String[] metaValue_generic_AmPmMarkers = new String[] {
+        final String[] metaValue_generic_narrow_AmPmMarkers = new String[] {
             "\u092d\u094b\u0930",
             "\u0938\u093e\u0902\u091d",
             "",
@@ -134,7 +134,7 @@ public class FormatData_mai extends ListResourceBundle {
             "\u0924\u093f3",
             "\u0924\u093f4",
         };
-        final String[] metaValue_long_Eras = new String[] {
+        final String[] metaValue_java_time_long_Eras = new String[] {
             "\u0908\u0938\u093e-\u092a\u0942\u0930\u094d\u0935",
             "\u0908\u0938\u0935\u0940",
         };
@@ -218,15 +218,21 @@ public class FormatData_mai extends ListResourceBundle {
             "GGGG d/M/y",
         };
         final String metaValue_calendarname_gregorian = "\u0917\u094d\u0930\u0947\u0917\u094b\u0930\u093f\u092f\u0928 \u0915\u0948\u0932\u0947\u0902\u0921\u0930";
+        final String[] metaValue_ListPatterns_standard = new String[] {
+            "",
+            "",
+            "{0}, \u0914\u0930 {1}",
+            "{0} \u0914\u0930 {1}",
+            "",
+        };
         final Object[][] data = new Object[][] {
             { "generic.DayNames", metaValue_generic_DayNames },
             { "generic.DayAbbreviations", metaValue_generic_DayAbbreviations },
             { "generic.DayNarrows", metaValue_generic_DayNarrows },
             { "generic.QuarterNames", metaValue_generic_QuarterNames },
             { "generic.QuarterAbbreviations", metaValue_generic_QuarterAbbreviations },
-            { "generic.AmPmMarkers", metaValue_generic_AmPmMarkers },
-            { "generic.narrow.AmPmMarkers", metaValue_generic_AmPmMarkers },
-            { "generic.abbreviated.AmPmMarkers", metaValue_generic_AmPmMarkers },
+            { "generic.narrow.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
+            { "generic.abbreviated.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
             { "generic.TimePatterns", metaValue_generic_TimePatterns },
             { "java.time.generic.DatePatterns", metaValue_java_time_generic_DatePatterns },
             { "generic.DatePatterns", metaValue_generic_DatePatterns },
@@ -304,12 +310,15 @@ public class FormatData_mai extends ListResourceBundle {
             { "standalone.QuarterNames", metaValue_generic_QuarterNames },
             { "QuarterAbbreviations", metaValue_generic_QuarterAbbreviations },
             { "standalone.QuarterAbbreviations", metaValue_generic_QuarterAbbreviations },
-            { "AmPmMarkers", metaValue_generic_AmPmMarkers },
-            { "narrow.AmPmMarkers", metaValue_generic_AmPmMarkers },
-            { "abbreviated.AmPmMarkers", metaValue_generic_AmPmMarkers },
-            { "long.Eras", metaValue_long_Eras },
-            { "Eras", metaValue_long_Eras },
-            { "narrow.Eras", metaValue_long_Eras },
+            { "AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
+            { "narrow.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
+            { "abbreviated.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
+            { "java.time.long.Eras", metaValue_java_time_long_Eras },
+            { "long.Eras", metaValue_java_time_long_Eras },
+            { "java.time.Eras", metaValue_java_time_long_Eras },
+            { "Eras", metaValue_java_time_long_Eras },
+            { "java.time.narrow.Eras", metaValue_java_time_long_Eras },
+            { "narrow.Eras", metaValue_java_time_long_Eras },
             { "field.era", "\u092e\u0939\u0940\u0928\u093e \u0915\u0947\u0930 \u0938\u092a\u094d\u0924\u093e\u0939" },
             { "field.year", "\u0935\u0930\u094d\u0937" },
             { "field.month", "\u092e\u0939\u0940\u0928\u093e" },
@@ -362,15 +371,13 @@ public class FormatData_mai extends ListResourceBundle {
             { "DateFormatItem.yQQQQ", metaValue_generic_DateFormatItem_yQQQQ },
             { "buddhist.MonthNames", metaValue_MonthNames },
             { "buddhist.MonthAbbreviations", metaValue_MonthAbbreviations },
-            { "buddhist.MonthNarrows", metaValue_MonthNarrows },
             { "buddhist.DayNames", metaValue_generic_DayNames },
             { "buddhist.DayAbbreviations", metaValue_generic_DayAbbreviations },
-            { "buddhist.DayNarrows", metaValue_generic_DayNarrows },
             { "buddhist.QuarterNames", metaValue_generic_QuarterNames },
             { "buddhist.QuarterAbbreviations", metaValue_generic_QuarterAbbreviations },
-            { "buddhist.AmPmMarkers", metaValue_generic_AmPmMarkers },
-            { "buddhist.narrow.AmPmMarkers", metaValue_generic_AmPmMarkers },
-            { "buddhist.abbreviated.AmPmMarkers", metaValue_generic_AmPmMarkers },
+            { "buddhist.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
+            { "buddhist.narrow.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
+            { "buddhist.abbreviated.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
             { "buddhist.TimePatterns", metaValue_generic_TimePatterns },
             { "java.time.buddhist.DatePatterns", metaValue_java_time_generic_DatePatterns },
             { "buddhist.DatePatterns", metaValue_generic_DatePatterns },
@@ -401,17 +408,22 @@ public class FormatData_mai extends ListResourceBundle {
             { "buddhist.DateFormatItem.yQQQQ", metaValue_generic_DateFormatItem_yQQQQ },
             { "japanese.MonthNames", metaValue_MonthNames },
             { "japanese.MonthAbbreviations", metaValue_MonthAbbreviations },
-            { "japanese.MonthNarrows", metaValue_MonthNarrows },
             { "japanese.DayNames", metaValue_generic_DayNames },
             { "japanese.DayAbbreviations", metaValue_generic_DayAbbreviations },
-            { "japanese.DayNarrows", metaValue_generic_DayNarrows },
             { "japanese.QuarterNames", metaValue_generic_QuarterNames },
             { "japanese.QuarterAbbreviations", metaValue_generic_QuarterAbbreviations },
-            { "japanese.AmPmMarkers", metaValue_generic_AmPmMarkers },
-            { "japanese.abbreviated.AmPmMarkers", metaValue_generic_AmPmMarkers },
+            { "japanese.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
+            { "japanese.abbreviated.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
             { "japanese.TimePatterns", metaValue_generic_TimePatterns },
             { "java.time.japanese.DatePatterns", metaValue_java_time_generic_DatePatterns },
-            { "japanese.DatePatterns", metaValue_generic_DatePatterns },
+            { "japanese.DatePatterns",
+                new String[] {
+                    "GGGG EEEE, d MMMM yyyy",
+                    "GGGG d MMMM yyyy",
+                    "GGGG d MMM y",
+                    "GGGG d/M/y",
+                }
+            },
             { "japanese.DateFormatItem.Gy", metaValue_generic_DateFormatItem_Gy },
             { "japanese.DateFormatItem.yQQQ", metaValue_generic_DateFormatItem_yQQQ },
             { "japanese.DateFormatItem.EBhm", metaValue_generic_DateFormatItem_EBhm },
@@ -439,14 +451,12 @@ public class FormatData_mai extends ListResourceBundle {
             { "japanese.DateFormatItem.yQQQQ", metaValue_generic_DateFormatItem_yQQQQ },
             { "roc.MonthNames", metaValue_MonthNames },
             { "roc.MonthAbbreviations", metaValue_MonthAbbreviations },
-            { "roc.MonthNarrows", metaValue_MonthNarrows },
             { "roc.DayNames", metaValue_generic_DayNames },
             { "roc.DayAbbreviations", metaValue_generic_DayAbbreviations },
             { "roc.DayNarrows", metaValue_generic_DayNarrows },
             { "roc.QuarterNames", metaValue_generic_QuarterNames },
             { "roc.QuarterAbbreviations", metaValue_generic_QuarterAbbreviations },
-            { "roc.AmPmMarkers", metaValue_generic_AmPmMarkers },
-            { "roc.abbreviated.AmPmMarkers", metaValue_generic_AmPmMarkers },
+            { "roc.abbreviated.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
             { "roc.TimePatterns", metaValue_generic_TimePatterns },
             { "java.time.roc.DatePatterns", metaValue_java_time_generic_DatePatterns },
             { "roc.DatePatterns", metaValue_generic_DatePatterns },
@@ -477,11 +487,9 @@ public class FormatData_mai extends ListResourceBundle {
             { "roc.DateFormatItem.yQQQQ", metaValue_generic_DateFormatItem_yQQQQ },
             { "islamic.DayNames", metaValue_generic_DayNames },
             { "islamic.DayAbbreviations", metaValue_generic_DayAbbreviations },
-            { "islamic.DayNarrows", metaValue_generic_DayNarrows },
             { "islamic.QuarterNames", metaValue_generic_QuarterNames },
             { "islamic.QuarterAbbreviations", metaValue_generic_QuarterAbbreviations },
-            { "islamic.AmPmMarkers", metaValue_generic_AmPmMarkers },
-            { "islamic.abbreviated.AmPmMarkers", metaValue_generic_AmPmMarkers },
+            { "islamic.abbreviated.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
             { "islamic.TimePatterns", metaValue_generic_TimePatterns },
             { "java.time.islamic.DatePatterns", metaValue_java_time_generic_DatePatterns },
             { "islamic.DatePatterns", metaValue_generic_DatePatterns },
@@ -568,6 +576,12 @@ public class FormatData_mai extends ListResourceBundle {
             { "calendarname.islamic-umalqura", "\u0907\u0938\u094d\u0932\u093e\u092e\u093f\u0915 \u0915\u0948\u0932\u0947\u0902\u0921\u0930 (\u0909\u092e \u0905\u0932 \u0915\u0941\u0930\u093e)" },
             { "calendarname.gregorian", metaValue_calendarname_gregorian },
             { "calendarname.gregory", metaValue_calendarname_gregorian },
+            { "ListPatterns_standard", metaValue_ListPatterns_standard },
+            { "ListPatterns_standard-short", metaValue_ListPatterns_standard },
+            { "ListPatterns_standard-narrow", metaValue_ListPatterns_standard },
+            { "ListPatterns_unit", metaValue_ListPatterns_standard },
+            { "ListPatterns_unit-short", metaValue_ListPatterns_standard },
+            { "ListPatterns_unit-narrow", metaValue_ListPatterns_standard },
         };
         return data;
     }
